@@ -2,7 +2,7 @@ from datetime import datetime
 from pathlib import Path
 from typing import Callable
 
-from digital_experiments.random import truly_random as rand
+from digital_experiments.random import truly_random
 
 me = Path(__file__).parent
 nouns = (me / "nouns.txt").read_text().split()
@@ -19,8 +19,8 @@ def new_experiment_id(rejection_function: Callable = None) -> Path:
         id = "-".join(
             (
                 datetime.now().strftime("%y%m%d-%H%M%S-%f")[:-2],
-                rand.choice(adjectives),
-                rand.choice(nouns),
+                truly_random.choice(adjectives),
+                truly_random.choice(nouns),
             )
         )
         if not rejection_function(id):
