@@ -7,7 +7,7 @@ import sys
 from collections.abc import Mapping
 from datetime import datetime
 from pathlib import Path
-from typing import Any, Dict
+from typing import Any, Callable, Dict
 
 import numpy as np
 
@@ -20,6 +20,10 @@ def first(iterable):
     return next(iter(iterable))
 
 
+def root_dir_for(experiment: Callable):
+    return "experiments/" + experiment.__name__
+
+
 def flatten(_dict, seperator="."):
     """
     flatten nested dicts into a single level
